* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    twostep.do
* Title:   Creates the dataset twostep.dta
*          used for estimations in Tables 1 to 5
* --------------------------------------------------------------------

set more off
clear

* --------------------------------------------------------------------
* use country data
* --------------------------------------------------------------------

use countries.dta, clear

* --------------------------------------------------------------------
* create new variables
* --------------------------------------------------------------------

generate phones_sc = phones/1000
lab var phones_sc "= phones/1000"

generate lphones_sc = ln(phones_sc)
lab var lphones_sc "= ln(phones_sc)"

generate internet_sc = internet/1000
lab var internet_sc "= internet/1000"

generate linternet_sc = ln(internet_sc)
lab var linternet_sc "= ln(internet_sc)"

generate nonagriva = (1-agriva)
lab var nonagriva "= (1-agriva)"

generate lnarea = log(landarea)
lab var lnarea "= log(landarea)"

generate lngdppcppp = log(gdppcppp)
lab var lngdppcppp "= log(gdppcppp)"

tsset countryid year
generate gdpgrowth = lngdppcppp - l.lngdppcppp
lab var gdpgrowth "= lngdppcppp - l.lngdppcppp"

by countryid: egen gdpgrowth_sd = sd(gdpgrowth)
lab var gdpgrowth_sd "= sd(gdpgrowth), by country"

generate roaddens = (roads/landarea)*100
lab var roaddens "= (roads/landarea)*100"

generate invroaddens = 1/roaddens 
lab var invroaddens "= 1/roaddens"

generate lnpop = log(pop)
lab var lnpop "= log(pop)"

generate govexp_mix = govexp
replace  govexp_mix = govexp_ktsoo if govexp == .
lab var govexp_mix "= govexp | = govexp_ktsoo if govexp == ."

generate time = year - 1980
lab var time "= year - 1980"

replace monopubyear = 1980 if monopubyear == -1
replace monopubyear = 2001 if monopubyear == 9999
generate monopubtime = monopubyear - 1980
generate timeaftermonopub = (time - monopubtime)*((time - monopubtime)>0)
lab var timeaftermonopub "years after end public monopoly"
drop monopubtime

replace monoprivyear = 1980 if monoprivyear == -1
replace monoprivyear = 2001 if monoprivyear == 9999
generate monoprivtime = monoprivyear - 1980
generate timeaftermonopriv = (time - monoprivtime)*((time - monoprivtime)>0)
lab var timeaftermonopriv "years after end private monopoly"
drop monoprivtime

aorder oecdyear - govexp_mix
order countrycode - oceania

* --------------------------------------------------------------------
* merge Zipf coefficients and more measure
* --------------------------------------------------------------------

* merge Zipf
sort countrycode year
merge countrycode year using zipf.dta
drop _merge

generate obs_cities_sc = obs_cities/1000
lab var obs_cities_sc "= obs_cities/1000"

* merge more measures
sort countrycode year
merge countrycode year using moremeasures.dta
drop _merge

* keep only years with city data
drop if obs_cities == .

* --------------------------------------------------------------------
* save data
* --------------------------------------------------------------------

save twostep.dta, replace




