* --------------------------------------------------------------------
* Project: The Effect of Information and Communication Technologies
*          on Urban Structure 
*          published in: Economic Policy, April 2008, pp. 201 - 242
* Authors: Yannis M. Ioannides, Henry G. Overman, 
*          Esteban Rossi-Hansberg, and Kurt Schmidheiny 
* Date:    December 7, 2007
* File:    zipf.do
* Title:   Estimate Zipf coefficients by country and year
* --------------------------------------------------------------------

set more off
clear
use cities.dta, clear

* rank cities by population
drop if popcity == .
drop if popcity < threshold
bysort countryname year: egen rank=rank(-popcity)
sort countryname year rank

* calculate logs
gen logrank = log(rank)
gen logrank05 = log(rank-0.5)
gen logpop = log(popcity)

* assign number of every country-year pair
sort countryname year
egen countryyear = group(countryname year)

* liner regression
gen obs_cities = .
gen min_cities = .
gen max_cities = .
gen alpha_lin_cities = .
gen sealpha_lin_cities = .
gen alpha05_lin_cities = .
gen sealpha05_lin_cities = .
gen seolsalpha05_lin_cities = .

forvalues num = 1(1)1500 {
   quietly sum popcity if countryyear == `num'
   if r(N) > 1 {
      replace min_cities = r(min) if countryyear == `num'
      replace max_cities = r(max) if countryyear == `num'
      regress logrank logpop if countryyear == `num'
      replace obs_cities = e(N) if countryyear == `num'
      replace alpha_lin_cities = _b[logpop] if countryyear == `num'
      replace sealpha_lin_cities = _se[logpop] if countryyear == `num'
      regress logrank05 logpop if countryyear == `num'
      replace alpha05_lin_cities = _b[logpop] if countryyear == `num'
      replace sealpha05_lin_cities = sqrt(2/e(N))*abs(_b[logpop]) if countryyear == `num'
      replace seolsalpha05_lin_cities = _se[logpop] if countryyear == `num'
   }
}

* covered population
generate pop_cities = popcity

* consolidate results
drop if obs_ == .
collapse (sum) pop_ (mean) obs min max alpha_ sealpha_ alpha05_ sealpha05_ seolsalpha05_, by(countrycode year)
label var pop_cities "total population in city sample"
label var obs_cities "number of cities in 1st stage regression"
label var min_cities "Pop. smallest city in 1st stage regression"
label var max_cities "Pop. largest city in 1st stage regression"
label var alpha_lin_cities "slope of linear regression"
label var sealpha_lin_cities "std. error of slope of linear regression"
label var alpha05_lin_cities "slope of linear regression, rank-0.5"
label var sealpha05_lin_cities "Correct std. error of slope of linear regression, rank-0.5"
label var seolsalpha05_lin_cities "OLS std. error of slope of linear regression, rank-0.5"

* create time variable with wave
sort countrycode year
by countrycode: egen wave_cities = seq()
lab var wave_cities "Wave of observation"

sort countrycode year

* save results
save zipf, replace
